import cv2  # importation d'open-CV-Python

# Script permettant de faire la correspondance entre le repère de la caméra et celui de la feuille A4 :
# Démarche : il s'agit de superposer une mire représentant le repère de la caméra avec une mire représentant
# le repère de la feuille.
# Appuyer sur la touche 'q' une fois la correspondance des mires réalisée

# choix de la source de la caméra (0 pour une webcam intégrée à l'ordinateur, 1 pour une webcam externe sur port USB)
cap = cv2.VideoCapture(1,cv2.CAP_DSHOW)
# initialisation de la résolution (axe X (colonne) = 1920 px, axe Y (ligne) = 1080 px)
cap.set(cv2.CAP_PROP_FRAME_WIDTH, 1920)
cap.set(cv2.CAP_PROP_FRAME_HEIGHT, 1080)

print('appuyer sur la touche \'q\' pour finaliser la calibration')

mire_px = 300
epaisseur = 2  # épaisseur du trait de la mire
# boucle infinie
while True:
    ret, img = cap.read()  # retourne une image dans la variable img
    # superpose sur l'image une mire bleue (système BGR) au centre (960, 540 px) de l'image
    cv2.line(img, (960, 540 - int(mire_px/2)), (960, 540 + int(mire_px/2)), (255, 0, 0), epaisseur)  # trait vertical
    cv2.line(img, (960 - int(mire_px/2), 540), (960 + int(mire_px/2), 540), (255, 0, 0), epaisseur)  # trait horizontal
    cv2.imshow('image + mire', img)  # affiche l'image 'img' dans la fenêtre 'image + mire'
    if cv2.waitKey(1) & 0xFF == ord('q'):  # attend appui sur la touche 'q' pour quitter la boucle infinie
        break

cv2.imwrite('calibration_finale.png', img)  # sauvegarde de l'image 'img' dans le fichier 'calibration_finale.png'
cap.release()  # ferme le flux caméra pour libérer des ressources
cv2.destroyAllWindows()  # détruit toutes les fenêtres
