import numpy
import threading
import DobotDllType as dType

# Dobot_commande ______________________________________________________________
# Il s'agit de programmer la mise en mouvement en ligne droite de la pointe du Feutre vers les centres des cercles
# détectés par la caméra sachant que le bras du robot devra rejoindre le point de coordonnée (x=250, y=0, z=50 mm)
# à l’issue de chaque descente vers le centre d’un cercle. Pour exprimer dans le repère de base du robot (R_0)
# des coordonnées exprimées dans le repère Feuille, on doit fixer :
#  - la valeur du vecteur O_0 O_F dans le repère de base du robot (R_0) (utiliser pour cela l'appli DobotStudio),
#  - la valeur de l'angle en rd entre X_0 et X_Feuille

CON_STR = {
    dType.DobotConnect.DobotConnect_NoError:  "DobotConnect_NoError",
    dType.DobotConnect.DobotConnect_NotFound: "DobotConnect_NotFound",
    dType.DobotConnect.DobotConnect_Occupied: "DobotConnect_Occupied"}

#Load Dll
api = dType.load()

#Connect Dobot
state = dType.ConnectDobot(api, "", 115200)[0]
print("Connect status:",CON_STR[state])

if (state == dType.DobotConnect.DobotConnect_NoError):

    #Clean Command Queued
    dType.SetQueuedCmdClear(api)

    #Async Motion Params Setting
    dType.SetHOMEParams(api, 250, 0, 50, 0, isQueued = 1)
    dType.SetPTPJointParams(api, 200, 200, 200, 200, 200, 200, 200, 200, isQueued = 1)
    dType.SetPTPCommonParams(api, 100, 100, isQueued = 1)

    #Setting the offset of the end-effector
    # outil correspondant à la pointe du Feutre (X_bias=61, Y_bias=0, Z_bias= 82.7 mm)
    dType.SetEndEffectorParams(api, 61, 0, 82.7, isQueued=1)

    #Commande Home
    dType.SetHOMECmd(api, temp = 0, isQueued = 1)

    # !! Partie à compléter pour permettre le passage du repère Feuille au repère de base du robot
    # calculer le vecteur O_0 O_F (de dimension 3x1) dans le repère de base du robot (R_0)
    # O_0_O_F = numpy.array([[??], [??], [??]])  # en mm
    # calculer la matrice de rotation R (de dimension 3x3) permettant le passage de R_0 à R_Feuille
    # R = ??

    #Async PTP Motion
    j = 0  # pour mémoriser le centre des cercles détectés dans R_0
    for i in center_mm:
        center_cm_R_0 = numpy.add(O_0_O_F, numpy.dot(R, numpy.array([[i[0]], [i[1]], [0]])))
        lastIndex = dType.SetPTPCmd(api, dType.PTPMode.PTPMOVLXYZMode, center_cm_R_0[0], center_cm_R_0[1], center_cm_R_0[2], 0, isQueued=1)[0]
        lastIndex = dType.SetPTPCmd(api, dType.PTPMode.PTPMOVLXYZMode, 250, 0, 50, 0, isQueued=1)[0]

    #Start to Execute Command Queued
    dType.SetQueuedCmdStartExec(api)

    #Wait for Executing Last Command 
    while lastIndex > dType.GetQueuedCmdCurrentIndex(api)[0]:
        dType.dSleep(100)

    #Stop to Execute Command Queued
    dType.SetQueuedCmdStopExec(api)

#Disconnect Dobot
dType.DisconnectDobot(api)
