import cv2  # importation d'open-CV-Python
import numpy

# choix de la source de la caméra (0 pour une webcam intégrée à l'ordinateur, 1 pour une webcam externe sur port USB)
cap = cv2.VideoCapture(1,cv2.CAP_DSHOW)
# initialisation de la résolution (axe X = 1920, axe Y = 1080 px)
cap.set(cv2.CAP_PROP_FRAME_WIDTH, 1920)
cap.set(cv2.CAP_PROP_FRAME_HEIGHT, 1080)

ret, frame = cap.read()  # retourne une image dans la variable frame

# création d'un masque ne retenant qu'un format papier A4 (210 x 297 mm) (le papier étant situé au centre de l'image)
mire_px = 300
mask = numpy.zeros(frame.shape[:2], numpy.uint8)
mask[int(540-(210*mire_px/(2*100))) : int(540+(210*mire_px/(2*100))), int(960-(297*mire_px/(2*100))) : int(960+(297*mire_px/(2*100)))] = 255
# l'image originale est masquée au format A4
frame = cv2.bitwise_and(frame,frame,mask = mask)

cv2.imwrite('image_initiale_avec_masque_A4.png', frame)  # enregistre l'image 'frame' dans le fichier 'image_intiale_avec_masque_A4.png'
cap.release()  # ferme le flux caméra pour libérer des ressources
# passage de l'image enregistrée en niveaux de gris
img = cv2.imread('image_initiale_avec_masque_A4.png', cv2.IMREAD_GRAYSCALE)

seuil = 100  # valeur du seuil utilisée lors de la binarisation de l'image 'img' (chaque pixel est mis : à 0
# (noir) si sa valeur est < au seuil, à 255 (blanc)) sinon)
ret1, gray = cv2.threshold(img, seuil, 255, cv2.THRESH_BINARY)
cv2.imshow('image binaire', gray)  # affiche l'image 'gray' dans la fenêtre 'image binarisée'
cv2.waitKey(0)  # attend appui sur une touche pour ne plus afficher la fenêtre

# utilisation de la transformée de Hough (HoughCircles) pour détecter les cercles dans l'image 'gray'
rows = gray.shape[0]  # rows contient le nombre de ligne contenue dans l'image
circles = cv2.HoughCircles(gray, cv2.HOUGH_GRADIENT, 1, rows / 8, param1=100, param2=30, minRadius=1, maxRadius=300)

if circles is not None:
    print(circles.shape[1], 'cercle(s) détecté(s) :-)')
    center_mm = numpy.zeros((circles.shape[1], 2))
    j = 0
    circles = numpy.uint16(numpy.around(circles))
    for i in circles[0, :]:
        center_px = (i[0], i[1])
        print('centre X, Y (px) = ', center_px)
        # calcul de la variable center_mm[j, :] en fonction des variables i[0], i[1]
        center_mm[j, :] = [i[0], i[1]]
        print('centre X, Y (mm) = ', center_mm[j, 0], center_mm[j, 1])
        j = j+1
        # circle center
        cv2.circle(frame, center_px, 3, (0, 0, 255), 3)  # rouge (système BGR)
        # circle outline
        radius = i[2]
        cv2.circle(frame, center_px, radius, (0, 255, 0), 3)  # vert
    cv2.imshow('cercle avec centre', frame)  # affiche l'image 'img' dans la fenêtre 'cercle avec centre'
    cv2.waitKey(0)  # attend appui sur une touche pour ne plus afficher la fenêtre
    cv2.imwrite('cercle_avec_centre.png', frame)  # sauvegarde de l'image 'img' dans le fichier 'cercle_avec_centre.png'
else:
    print('aucun cercle détecté !!')

